==> ses-1.60.0-sources.jar: software/amazon/awscdk/services/ses/ReceiptRule.java <==
package software.amazon.awscdk.services.ses;

/**
 * A new receipt rule.
 * <p>
 * EXPERIMENTAL
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.9.0 (build 5c646d5)", date = "2020-08-19T23:25:15.450Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.ses.$Module.class, fqn = "@aws-cdk/aws-ses.ReceiptRule")
public class ReceiptRule extends software.amazon.awscdk.core.Resource implements software.amazon.awscdk.services.ses.IReceiptRule {

    protected ReceiptRule(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected ReceiptRule(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * EXPERIMENTAL
     * <p>
     * @param scope This parameter is required.
     * @param id This parameter is required.
     * @param props This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public ReceiptRule(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.core.Construct scope, final @org.jetbrains.annotations.NotNull java.lang.String id, final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.ses.ReceiptRuleProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(props, "props is required") });
    }

    /**
     * EXPERIMENTAL
     * <p>
     * @param scope This parameter is required.
     * @param id This parameter is required.
     * @param receiptRuleName This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.ses.IReceiptRule fromReceiptRuleName(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.core.Construct scope, final @org.jetbrains.annotations.NotNull java.lang.String id, final @org.jetbrains.annotations.NotNull java.lang.String receiptRuleName) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.ses.ReceiptRule.class, "fromReceiptRuleName", software.amazon.awscdk.services.ses.IReceiptRule.class, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(receiptRuleName, "receiptRuleName is required") });
    }

    /**
     * Adds an action to this receipt rule.
     * <p>
     * EXPERIMENTAL
     * <p>
     * @param action This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public void addAction(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.ses.IReceiptRuleAction action) {
        this.jsiiCall("addAction", software.amazon.jsii.NativeType.VOID, new Object[] { java.util.Objects.requireNonNull(action, "action is required") });
    }

    /**
     * The name of the receipt rule.
     * <p>
     * EXPERIMENTAL
     */
    @Override
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull java.lang.String getReceiptRuleName() {
        return this.jsiiGet("receiptRuleName", java.lang.String.class);
    }

    /**
     * A fluent builder for {@link software.amazon.awscdk.services.ses.ReceiptRule}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<software.amazon.awscdk.services.ses.ReceiptRule> {
        /**
         * EXPERIMENTAL
         * <p>
         * @return a new instance of {@link Builder}.
         * @param scope This parameter is required.
         * @param id This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public static Builder create(final software.amazon.awscdk.core.Construct scope, final java.lang.String id) {
            return new Builder(scope, id);
        }

        private final software.amazon.awscdk.core.Construct scope;
        private final java.lang.String id;
        private final software.amazon.awscdk.services.ses.ReceiptRuleProps.Builder props;

        private Builder(final software.amazon.awscdk.core.Construct scope, final java.lang.String id) {
            this.scope = scope;
            this.id = id;
            this.props = new software.amazon.awscdk.services.ses.ReceiptRuleProps.Builder();
        }

        /**
         * An ordered list of actions to perform on messages that match at least one of the recipient email addresses or domains specified in the receipt rule.
         * <p>
         * Default: - No actions.
         * <p>
         * EXPERIMENTAL
         * <p>
         * @return {@code this}
         * @param actions An ordered list of actions to perform on messages that match at least one of the recipient email addresses or domains specified in the receipt rule. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder actions(final java.util.List<software.amazon.awscdk.services.ses.IReceiptRuleAction> actions) {
            this.props.actions(actions);
            return this;
        }

        /**
         * An existing rule after which the new rule will be placed.
         * <p>
         * Default: - The new rule is inserted at the beginning of the rule list.
         * <p>
         * EXPERIMENTAL
         * <p>
         * @return {@code this}
         * @param after An existing rule after which the new rule will be placed. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder after(final software.amazon.awscdk.services.ses.IReceiptRule after) {
            this.props.after(after);
            return this;
        }

        /**
         * Whether the rule is active.
         * <p>
         * Default: true
         * <p>
         * EXPERIMENTAL
         * <p>
         * @return {@code this}
         * @param enabled Whether the rule is active. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder enabled(final java.lang.Boolean enabled) {
            this.props.enabled(enabled);
            return this;
        }

        /**
         * The name for the rule.
         * <p>
         * Default: - A CloudFormation generated name.
         * <p>
         * EXPERIMENTAL
         * <p>
         * @return {@code this}
         * @param receiptRuleName The name for the rule. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder receiptRuleName(final java.lang.String receiptRuleName) {
            this.props.receiptRuleName(receiptRuleName);
            return this;
        }

        /**
         * The recipient domains and email addresses that the receipt rule applies to.
         * <p>
         * Default: - Match all recipients under all verified domains.
         * <p>
         * EXPERIMENTAL
         * <p>
         * @return {@code this}
         * @param recipients The recipient domains and email addresses that the receipt rule applies to. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder recipients(final java.util.List<java.lang.String> recipients) {
            this.props.recipients(recipients);
            return this;
        }

        /**
         * Whether to scan for spam and viruses.
         * <p>
         * Default: false
         * <p>
         * EXPERIMENTAL
         * <p>
         * @return {@code this}
         * @param scanEnabled Whether to scan for spam and viruses. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder scanEnabled(final java.lang.Boolean scanEnabled) {
            this.props.scanEnabled(scanEnabled);
            return this;
        }

        /**
         * Whether Amazon SES should require that incoming email is delivered over a connection encrypted with Transport Layer Security (TLS).
         * <p>
         * Default: - Optional which will not check for TLS.
         * <p>
         * EXPERIMENTAL
         * <p>
         * @return {@code this}
         * @param tlsPolicy Whether Amazon SES should require that incoming email is delivered over a connection encrypted with Transport Layer Security (TLS). This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder tlsPolicy(final software.amazon.awscdk.services.ses.TlsPolicy tlsPolicy) {
            this.props.tlsPolicy(tlsPolicy);
            return this;
        }

        /**
         * The name of the rule set that the receipt rule will be added to.
         * <p>
         * EXPERIMENTAL
         * <p>
         * @return {@code this}
         * @param ruleSet The name of the rule set that the receipt rule will be added to. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder ruleSet(final software.amazon.awscdk.services.ses.IReceiptRuleSet ruleSet) {
            this.props.ruleSet(ruleSet);
            return this;
        }

        /**
         * @returns a newly built instance of {@link software.amazon.awscdk.services.ses.ReceiptRule}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public software.amazon.awscdk.services.ses.ReceiptRule build() {
            return new software.amazon.awscdk.services.ses.ReceiptRule(
                this.scope,
                this.id,
                this.props.build()
            );
        }
    }
}

==> ses-1.173.0-sources.jar: software/amazon/awscdk/services/ses/ReceiptRule.java <==
package software.amazon.awscdk.services.ses;

/**
 * A new receipt rule.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * ReceiptRuleSet ruleSet = new ReceiptRuleSet(this, "RuleSet");
 * ReceiptRule awsRule = ruleSet.addRule("Aws", ReceiptRuleOptions.builder()
 *         .recipients(List.of("aws.com"))
 *         .build());
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.67.0 (build 2c027f5)", date = "2022-09-16T18:50:30.642Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.ses.$Module.class, fqn = "@aws-cdk/aws-ses.ReceiptRule")
public class ReceiptRule extends software.amazon.awscdk.core.Resource implements software.amazon.awscdk.services.ses.IReceiptRule {

    protected ReceiptRule(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected ReceiptRule(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param scope This parameter is required.
     * @param id This parameter is required.
     * @param props This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public ReceiptRule(final @org.jetbrains.annotations.NotNull software.constructs.Construct scope, final @org.jetbrains.annotations.NotNull java.lang.String id, final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.ses.ReceiptRuleProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(props, "props is required") });
    }

    /**
     * @param scope This parameter is required.
     * @param id This parameter is required.
     * @param receiptRuleName This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.ses.IReceiptRule fromReceiptRuleName(final @org.jetbrains.annotations.NotNull software.constructs.Construct scope, final @org.jetbrains.annotations.NotNull java.lang.String id, final @org.jetbrains.annotations.NotNull java.lang.String receiptRuleName) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.ses.ReceiptRule.class, "fromReceiptRuleName", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.ses.IReceiptRule.class), new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(receiptRuleName, "receiptRuleName is required") });
    }

    /**
     * Adds an action to this receipt rule.
     * <p>
     * @param action This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void addAction(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.ses.IReceiptRuleAction action) {
        software.amazon.jsii.Kernel.call(this, "addAction", software.amazon.jsii.NativeType.VOID, new Object[] { java.util.Objects.requireNonNull(action, "action is required") });
    }

    /**
     * The name of the receipt rule.
     */
    @Override
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull java.lang.String getReceiptRuleName() {
        return software.amazon.jsii.Kernel.get(this, "receiptRuleName", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     * A fluent builder for {@link software.amazon.awscdk.services.ses.ReceiptRule}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<software.amazon.awscdk.services.ses.ReceiptRule> {
        /**
         * @return a new instance of {@link Builder}.
         * @param scope This parameter is required.
         * @param id This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public static Builder create(final software.constructs.Construct scope, final java.lang.String id) {
            return new Builder(scope, id);
        }

        private final software.constructs.Construct scope;
        private final java.lang.String id;
        private final software.amazon.awscdk.services.ses.ReceiptRuleProps.Builder props;

        private Builder(final software.constructs.Construct scope, final java.lang.String id) {
            this.scope = scope;
            this.id = id;
            this.props = new software.amazon.awscdk.services.ses.ReceiptRuleProps.Builder();
        }

        /**
         * An ordered list of actions to perform on messages that match at least one of the recipient email addresses or domains specified in the receipt rule.
         * <p>
         * Default: - No actions.
         * <p>
         * @return {@code this}
         * @param actions An ordered list of actions to perform on messages that match at least one of the recipient email addresses or domains specified in the receipt rule. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder actions(final java.util.List<? extends software.amazon.awscdk.services.ses.IReceiptRuleAction> actions) {
            this.props.actions(actions);
            return this;
        }

        /**
         * An existing rule after which the new rule will be placed.
         * <p>
         * Default: - The new rule is inserted at the beginning of the rule list.
         * <p>
         * @return {@code this}
         * @param after An existing rule after which the new rule will be placed. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder after(final software.amazon.awscdk.services.ses.IReceiptRule after) {
            this.props.after(after);
            return this;
        }

        /**
         * Whether the rule is active.
         * <p>
         * Default: true
         * <p>
         * @return {@code this}
         * @param enabled Whether the rule is active. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder enabled(final java.lang.Boolean enabled) {
            this.props.enabled(enabled);
            return this;
        }

        /**
         * The name for the rule.
         * <p>
         * Default: - A CloudFormation generated name.
         * <p>
         * @return {@code this}
         * @param receiptRuleName The name for the rule. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder receiptRuleName(final java.lang.String receiptRuleName) {
            this.props.receiptRuleName(receiptRuleName);
            return this;
        }

        /**
         * The recipient domains and email addresses that the receipt rule applies to.
         * <p>
         * Default: - Match all recipients under all verified domains.
         * <p>
         * @return {@code this}
         * @param recipients The recipient domains and email addresses that the receipt rule applies to. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder recipients(final java.util.List<java.lang.String> recipients) {
            this.props.recipients(recipients);
            return this;
        }

        /**
         * Whether to scan for spam and viruses.
         * <p>
         * Default: false
         * <p>
         * @return {@code this}
         * @param scanEnabled Whether to scan for spam and viruses. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder scanEnabled(final java.lang.Boolean scanEnabled) {
            this.props.scanEnabled(scanEnabled);
            return this;
        }

        /**
         * Whether Amazon SES should require that incoming email is delivered over a connection encrypted with Transport Layer Security (TLS).
         * <p>
         * Default: - Optional which will not check for TLS.
         * <p>
         * @return {@code this}
         * @param tlsPolicy Whether Amazon SES should require that incoming email is delivered over a connection encrypted with Transport Layer Security (TLS). This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder tlsPolicy(final software.amazon.awscdk.services.ses.TlsPolicy tlsPolicy) {
            this.props.tlsPolicy(tlsPolicy);
            return this;
        }

        /**
         * The name of the rule set that the receipt rule will be added to.
         * <p>
         * @return {@code this}
         * @param ruleSet The name of the rule set that the receipt rule will be added to. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder ruleSet(final software.amazon.awscdk.services.ses.IReceiptRuleSet ruleSet) {
            this.props.ruleSet(ruleSet);
            return this;
        }

        /**
         * @returns a newly built instance of {@link software.amazon.awscdk.services.ses.ReceiptRule}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public software.amazon.awscdk.services.ses.ReceiptRule build() {
            return new software.amazon.awscdk.services.ses.ReceiptRule(
                this.scope,
                this.id,
                this.props.build()
            );
        }
    }
}
